========
Spectrum
========

Sub-commands to support spectrum definition

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.spectrum.SPECTRUM
    rompy_swan.subcomponents.spectrum.SHAPESPEC
    rompy_swan.subcomponents.spectrum.JONSWAP
    rompy_swan.subcomponents.spectrum.TMA
    rompy_swan.subcomponents.spectrum.GAUSS
    rompy_swan.subcomponents.spectrum.PM
    rompy_swan.subcomponents.spectrum.BIN
